/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Joe Hewitt <hewitt@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/* ===== popup.css =====================================================
  == Styles used by the XUL popup & menupopup elements.
  ======================================================================= */

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

/* ::::: popup/menupopup ::::: */

.panel-arrowcontent,
panel:not([type="arrow"]),
menupopup,
popup {
  cursor: default;
  border: 2px solid;
  -moz-border-top-colors: #7F8893 #EEF4FC;
  -moz-border-right-colors: #7F8893 #B9BFC7;
  -moz-border-bottom-colors: #7F8893 #B9BFC7;
  -moz-border-left-colors: #7F8893 #EEF4FC;
  min-width: 1px;
  background-color: #DDE3EB;
  color: #22262F;
}

menupopup > menu > menupopup,
popup > menu > menupopup {
  margin: -2px;
}

/* Ideally we would set and forget a -16px margin around the entire panel.
   Unfortunately this makes the panel code think we're hiding the anchor,
   and it reacts by turning the arrow off. So instead we have to turn off
   the 16px border on the appropriate side of the arrow. */
panel[type="arrow"][side="top"],
panel[type="arrow"][side="bottom"] {
  margin: 0px -16px;
}

panel[type="arrow"][side="left"],
panel[type="arrow"][side="right"] {
  margin: -16px 0px;
}

/* The arrow is empty, but it has equal triangular borders on all four sides.
   We just have to turn on the border on the side touching the content. */
.panel-arrow {
  border: 16px solid transparent;
}

.panel-arrow[side="top"] {
  border-top-style: none;
  -moz-border-bottom-colors: #7F8893;
}

.panel-arrow[side="bottom"] {
  border-bottom-style: none;
  -moz-border-top-colors: #7F8893;
}

.panel-arrow[side="left"] {
  border-left-style: none;
  -moz-border-right-colors: #7F8893;
}

.panel-arrow[side="right"] {
  border-right-style: none;
  -moz-border-left-colors: #7F8893;
}

/* ::::: tooltip ::::: */

tooltip {
  margin-top: 21px;
  border: 1px solid #000000;
  padding: 2px 3px;
  max-width: 40em;
  background-color: #FFFFE7;
  color: #000000;
  font: message-box;
}

tooltip[titletip="true"] {
  /* See bug 32157 comment 128
   * margin-top: -2px;
   * margin-bottom: 0px;
   * -moz-margin-start: -4px;
   * -moz-margin-end: 0px;
   */
  max-width: none;
}

/* ::::: menulist popup :::::: */

menulist > menupopup,
.menulist-menupopup {
  border-width: 1px;
  -moz-border-top-colors: #000000;
  -moz-border-right-colors: #000000;
  -moz-border-bottom-colors: #000000;
  -moz-border-left-colors: #000000;
  padding: 0px;
  min-width: 0px;
}

menupopup > menu > .menulist-menupopup,
popup > menu > .menulist-menupopup {
  margin: -1px;
}
